@@ -221,14 +221,14 @@ get_app <- function(subdomain, auth, app_id, agent = NULL, include_sec = T, incl
     tibble::as_tibble()
 
 
-  if(include_sec){
+  if(include_sec & "securityProperties" %in% names(resp)){
     sec <- tibble::as_tibble(resp[["securityProperties"]])
     sec <- sec %>%
       dplyr::rename_with(~ paste0("sec_", names(sec)))
     app_data <- app_data %>% dplyr::bind_cols(sec)
   }
 
-  if(include_vars){
+  if(include_vars & "variables" %in% names(resp)){
     var <- tibble::as_tibble(resp[["variables"]]) %>%
       dplyr::mutate(name = paste0("var_", name)) %>%
       tidyr::pivot_wider(names_from = name, values_from = value)
